@@ -276,8 +276,12 @@ def _serve(callback,userCallback,callbacks ):
 def launch(callback, userCallback,callbacks,headContent):
 	global _headContent, _instances
 
-	_headContent = headContent
-
+	if headContent == None:
+		if not "_headContent" in globals():
+			_headContent = "" 
+	else:
+		_headContent = headContent
+	
 	_instances = {}
 
 	_init()
@@ -289,7 +293,7 @@ def launch(callback, userCallback,callbacks,headContent):
 	_serve(callback,userCallback,callbacks)
 
 def get_app_url(id=""):
-	return _url + ("&_id=" + id if id else "") 
+	return _url + ("&_id=" + str(id) if id else "") 
 
 def broadcastAction(action,id=""):
 	_writeLock.acquire()
